# Code of Conduct

## Our Pledge

We are committed to providing a welcoming, inclusive, and harassment-free experience for everyone, regardless of age, body size, disability, ethnicity, gender identity and expression, level of experience, nationality, personal appearance, race, religion, or sexual identity and orientation.

## Our Standards

**Positive behaviors include:**

- Using welcoming and inclusive language
- Respecting differing viewpoints and experiences
- Accepting constructive criticism gracefully
- Focusing on what is best for the community
- Showing empathy toward other community members

**Unacceptable behaviors include:**

- Trolling, insulting or derogatory comments, and personal or political attacks
- Public or private harassment
- Publishing others' private information without explicit permission
- Sexual language or imagery in any community space
- Other conduct which could reasonably be considered inappropriate in a professional setting

## Enforcement

Project maintainers are responsible for clarifying and enforcing standards of acceptable behavior. They have the right and responsibility to remove, edit, or reject comments, commits, code, issues, and other contributions that violate this Code of Conduct.

## Scope

This Code of Conduct applies within all project spaces (issues, pull requests, discussions) and when an individual is representing the project in public spaces.

## Reporting

Instances of abusive, harassing, or otherwise unacceptable behavior may be reported to the project maintainer through GitHub's private communication channels. All complaints will be reviewed and investigated promptly and fairly.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org/), version 2.1.
